{
    "$graph": [
        {
            "class": "Workflow",
            "label": "Unaligned to aligned BAM",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#align.cwl/bam"
                },
                {
                    "type": "string",
                    "id": "#align.cwl/readgroup"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict",
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "id": "#align.cwl/reference"
                }
            ],
            "steps": [
                {
                    "run": "#align_and_tag.cwl",
                    "in": [
                        {
                            "source": "#align.cwl/bam",
                            "id": "#align.cwl/align_and_tag/bam"
                        },
                        {
                            "source": "#align.cwl/readgroup",
                            "id": "#align.cwl/align_and_tag/readgroup"
                        },
                        {
                            "source": "#align.cwl/reference",
                            "id": "#align.cwl/align_and_tag/reference"
                        }
                    ],
                    "out": [
                        "#align.cwl/align_and_tag/aligned_bam"
                    ],
                    "id": "#align.cwl/align_and_tag"
                }
            ],
            "id": "#align.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#align.cwl/align_and_tag/aligned_bam",
                    "id": "#align.cwl/tagged_bam"
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "Unaligned BAM to BQSR",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#bam_to_bqsr.cwl/bams"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "id": "#bam_to_bqsr.cwl/bqsr_intervals"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#bam_to_bqsr.cwl/dbsnp_vcf"
                },
                {
                    "type": "string",
                    "default": "final.bam",
                    "id": "#bam_to_bqsr.cwl/final_name"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#bam_to_bqsr.cwl/known_indels"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#bam_to_bqsr.cwl/mills"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#bam_to_bqsr.cwl/readgroups"
                },
                {
                    "type": "string",
                    "id": "#bam_to_bqsr.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#bam_to_bqsr.cwl/index_bam/indexed_bam",
                    "secondaryFiles": [
                        ".bai",
                        "^.bai"
                    ],
                    "id": "#bam_to_bqsr.cwl/final_bam"
                },
                {
                    "type": "File",
                    "outputSource": "#bam_to_bqsr.cwl/mark_duplicates_and_sort/metrics_file",
                    "id": "#bam_to_bqsr.cwl/mark_duplicates_metrics_file"
                }
            ],
            "steps": [
                {
                    "scatter": [
                        "#bam_to_bqsr.cwl/align/bam",
                        "#bam_to_bqsr.cwl/align/readgroup"
                    ],
                    "scatterMethod": "dotproduct",
                    "run": "#align.cwl",
                    "in": [
                        {
                            "source": "#bam_to_bqsr.cwl/bams",
                            "id": "#bam_to_bqsr.cwl/align/bam"
                        },
                        {
                            "source": "#bam_to_bqsr.cwl/readgroups",
                            "id": "#bam_to_bqsr.cwl/align/readgroup"
                        },
                        {
                            "source": "#bam_to_bqsr.cwl/reference",
                            "id": "#bam_to_bqsr.cwl/align/reference"
                        }
                    ],
                    "out": [
                        "#bam_to_bqsr.cwl/align/tagged_bam"
                    ],
                    "id": "#bam_to_bqsr.cwl/align"
                },
                {
                    "run": "#apply_bqsr.cwl",
                    "in": [
                        {
                            "source": "#bam_to_bqsr.cwl/mark_duplicates_and_sort/sorted_bam",
                            "id": "#bam_to_bqsr.cwl/apply_bqsr/bam"
                        },
                        {
                            "source": "#bam_to_bqsr.cwl/bqsr/bqsr_table",
                            "id": "#bam_to_bqsr.cwl/apply_bqsr/bqsr_table"
                        },
                        {
                            "source": "#bam_to_bqsr.cwl/final_name",
                            "id": "#bam_to_bqsr.cwl/apply_bqsr/output_name"
                        },
                        {
                            "source": "#bam_to_bqsr.cwl/reference",
                            "id": "#bam_to_bqsr.cwl/apply_bqsr/reference"
                        }
                    ],
                    "out": [
                        "#bam_to_bqsr.cwl/apply_bqsr/bqsr_bam"
                    ],
                    "id": "#bam_to_bqsr.cwl/apply_bqsr"
                },
                {
                    "run": "#bqsr.cwl",
                    "in": [
                        {
                            "source": "#bam_to_bqsr.cwl/mark_duplicates_and_sort/sorted_bam",
                            "id": "#bam_to_bqsr.cwl/bqsr/bam"
                        },
                        {
                            "source": "#bam_to_bqsr.cwl/bqsr_intervals",
                            "id": "#bam_to_bqsr.cwl/bqsr/intervals"
                        },
                        {
                            "source": [
                                "#bam_to_bqsr.cwl/dbsnp_vcf",
                                "#bam_to_bqsr.cwl/mills",
                                "#bam_to_bqsr.cwl/known_indels"
                            ],
                            "id": "#bam_to_bqsr.cwl/bqsr/known_sites"
                        },
                        {
                            "source": "#bam_to_bqsr.cwl/reference",
                            "id": "#bam_to_bqsr.cwl/bqsr/reference"
                        }
                    ],
                    "out": [
                        "#bam_to_bqsr.cwl/bqsr/bqsr_table"
                    ],
                    "id": "#bam_to_bqsr.cwl/bqsr"
                },
                {
                    "run": "#index_bam.cwl",
                    "in": [
                        {
                            "source": "#bam_to_bqsr.cwl/apply_bqsr/bqsr_bam",
                            "id": "#bam_to_bqsr.cwl/index_bam/bam"
                        }
                    ],
                    "out": [
                        "#bam_to_bqsr.cwl/index_bam/indexed_bam"
                    ],
                    "id": "#bam_to_bqsr.cwl/index_bam"
                },
                {
                    "run": "#mark_duplicates_and_sort.cwl",
                    "in": [
                        {
                            "source": "#bam_to_bqsr.cwl/name_sort/name_sorted_bam",
                            "id": "#bam_to_bqsr.cwl/mark_duplicates_and_sort/bam"
                        }
                    ],
                    "out": [
                        "#bam_to_bqsr.cwl/mark_duplicates_and_sort/sorted_bam",
                        "#bam_to_bqsr.cwl/mark_duplicates_and_sort/metrics_file"
                    ],
                    "id": "#bam_to_bqsr.cwl/mark_duplicates_and_sort"
                },
                {
                    "run": "#merge_bams_samtools.cwl",
                    "in": [
                        {
                            "source": "#bam_to_bqsr.cwl/align/tagged_bam",
                            "id": "#bam_to_bqsr.cwl/merge/bams"
                        },
                        {
                            "source": "#bam_to_bqsr.cwl/final_name",
                            "id": "#bam_to_bqsr.cwl/merge/name"
                        }
                    ],
                    "out": [
                        "#bam_to_bqsr.cwl/merge/merged_bam"
                    ],
                    "id": "#bam_to_bqsr.cwl/merge"
                },
                {
                    "run": "#name_sort.cwl",
                    "in": [
                        {
                            "source": "#bam_to_bqsr.cwl/merge/merged_bam",
                            "id": "#bam_to_bqsr.cwl/name_sort/bam"
                        }
                    ],
                    "out": [
                        "#bam_to_bqsr.cwl/name_sort/name_sorted_bam"
                    ],
                    "id": "#bam_to_bqsr.cwl/name_sort"
                }
            ],
            "id": "#bam_to_bqsr.cwl"
        },
        {
            "class": "Workflow",
            "label": "downsample unaligned BAM and align",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/bams"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/dbsnp_vcf"
                },
                {
                    "type": "float",
                    "id": "#main/downsample_probability"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/known_indels"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/mills"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/readgroups"
                },
                {
                    "type": "string",
                    "id": "#main/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/align_workflow/final_bam",
                    "secondaryFiles": [
                        ".bai",
                        "^.bai"
                    ],
                    "id": "#main/bam"
                },
                {
                    "type": "File",
                    "outputSource": "#main/align_workflow/mark_duplicates_metrics_file",
                    "id": "#main/mark_duplicates_metrics_file"
                }
            ],
            "steps": [
                {
                    "run": "#bam_to_bqsr.cwl",
                    "in": [
                        {
                            "source": "#main/downsample/downsampled_sam",
                            "id": "#main/align_workflow/bams"
                        },
                        {
                            "source": "#main/dbsnp_vcf",
                            "id": "#main/align_workflow/dbsnp_vcf"
                        },
                        {
                            "source": "#main/known_indels",
                            "id": "#main/align_workflow/known_indels"
                        },
                        {
                            "source": "#main/mills",
                            "id": "#main/align_workflow/mills"
                        },
                        {
                            "source": "#main/readgroups",
                            "id": "#main/align_workflow/readgroups"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/align_workflow/reference"
                        }
                    ],
                    "out": [
                        "#main/align_workflow/final_bam",
                        "#main/align_workflow/mark_duplicates_metrics_file"
                    ],
                    "id": "#main/align_workflow"
                },
                {
                    "scatter": [
                        "#main/downsample/sam"
                    ],
                    "scatterMethod": "dotproduct",
                    "run": "#downsample.cwl",
                    "in": [
                        {
                            "source": "#main/downsample_probability",
                            "id": "#main/downsample/probability"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/downsample/reference"
                        },
                        {
                            "source": "#main/bams",
                            "id": "#main/downsample/sam"
                        }
                    ],
                    "out": [
                        "#main/downsample/downsampled_sam"
                    ],
                    "id": "#main/downsample"
                }
            ],
            "id": "#main"
        },
        {
            "class": "CommandLineTool",
            "label": "align with bwa_mem and tag",
            "baseCommand": [
                "/bin/bash",
                "/usr/bin/alignment_helper.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 8,
                    "ramMin": 20000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/alignment_helper-cwl:1.0.0"
                }
            ],
            "stdout": "refAlign.bam",
            "arguments": [
                {
                    "position": 4,
                    "valueFrom": "$(runtime.cores)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#align_and_tag.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#align_and_tag.cwl/readgroup"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#align_and_tag.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#align_and_tag.cwl/aligned_bam",
                    "outputBinding": {
                        "glob": "refAlign.bam"
                    }
                }
            ],
            "id": "#align_and_tag.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "apply BQSR",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "PrintReads"
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_name).bam"
                },
                "-preserveQ",
                "6",
                "-SQQ",
                "10",
                "-SQQ",
                "20",
                "-SQQ",
                "30",
                "-nct",
                "8",
                "--disable_indel_quals"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 18000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/gatk-cwl:3.6.0"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#apply_bqsr.cwl/bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-BQSR",
                        "position": 3
                    },
                    "id": "#apply_bqsr.cwl/bqsr_table"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "final",
                    "id": "#apply_bqsr.cwl/output_name"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#apply_bqsr.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_name).bam"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#apply_bqsr.cwl/bqsr_bam"
                }
            ],
            "id": "#apply_bqsr.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "create BQSR table",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "BaseRecalibrator"
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/bqsr.table"
                },
                "--preserve_qscores_less_than",
                "6",
                "--disable_auto_index_creation_and_locking_when_reading_rods",
                "--disable_bam_indexing",
                "-dfrac",
                ".1",
                "-nct",
                "4"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 18000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/gatk-cwl:3.6.0"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#bqsr.cwl/bam"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-L"
                        }
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "default": [
                        "chr1",
                        "chr2",
                        "chr3",
                        "chr4",
                        "chr5",
                        "chr6",
                        "chr7",
                        "chr8",
                        "chr9",
                        "chr10",
                        "chr11",
                        "chr12",
                        "chr13",
                        "chr14",
                        "chr15",
                        "chr16",
                        "chr17",
                        "chr18",
                        "chr19",
                        "chr20",
                        "chr21",
                        "chr22"
                    ],
                    "id": "#bqsr.cwl/intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "-knownSites",
                            "position": 4
                        }
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#bqsr.cwl/known_sites"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 2
                    },
                    "id": "#bqsr.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "bqsr.table"
                    },
                    "id": "#bqsr.cwl/bqsr_table"
                }
            ],
            "id": "#bqsr.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "downsample unaligned BAM",
            "baseCommand": [
                "/gatk/gatk",
                "--java-options",
                "-Xmx16g",
                "DownsampleSam"
            ],
            "arguments": [
                "--OUTPUT=",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.sam.nameroot).bam"
                },
                "--CREATE_INDEX",
                "--CREATE_MD5_FILE"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 18000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.1.4.1"
                }
            ],
            "inputs": [
                {
                    "type": "float",
                    "inputBinding": {
                        "prefix": "--PROBABILITY=",
                        "separate": false
                    },
                    "id": "#downsample.cwl/probability"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--RANDOM_SEED=",
                        "separate": false
                    },
                    "id": "#downsample.cwl/random_seed"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "--REFERENCE_SEQUENCE=",
                        "separate": false
                    },
                    "id": "#downsample.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--INPUT=",
                        "separate": false
                    },
                    "id": "#downsample.cwl/sam"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#downsample.cwl/strategy/HighAccuracy",
                                "#downsample.cwl/strategy/ConstantMemory",
                                "#downsample.cwl/strategy/Chained"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--STRATEGY=",
                        "separate": false
                    },
                    "id": "#downsample.cwl/strategy"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".md5",
                        "^.bai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.sam.nameroot).bam"
                    },
                    "id": "#downsample.cwl/downsampled_sam"
                }
            ],
            "id": "#downsample.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools index",
            "arguments": [
                "/opt/samtools/bin/samtools",
                "index",
                "$(runtime.outdir)/$(inputs.bam.basename)",
                "$(runtime.outdir)/$(inputs.bam.basename).bai",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "cp",
                "$(inputs.bam.basename).bai",
                "$(runtime.outdir)/$(inputs.bam.nameroot).bai"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        "${ var f = inputs.bam; delete f.secondaryFiles; return f }"
                    ]
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#index_bam.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai",
                        "^.bai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.bam.basename)"
                    },
                    "id": "#index_bam.cwl/indexed_bam"
                }
            ],
            "id": "#index_bam.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Mark duplicates and Sort",
            "baseCommand": [
                "/bin/bash",
                "markduplicates_helper.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 8,
                    "ramMin": 40000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/mark_duplicates-cwl:1.0.1"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "markduplicates_helper.sh",
                            "entry": "set -o pipefail\nset -o errexit\n\ndeclare MD_BARCODE_TAG\nif [ ! -z \"$6\" ]; then\n  MD_BARCODE_TAG=\"BARCODE_TAG=$6\"\n/usr/bin/java -Xmx16g -jar /opt/picard/picard.jar MarkDuplicates I=$1 O=/dev/stdout ASSUME_SORT_ORDER=$5 METRICS_FILE=$4 QUIET=true COMPRESSION_LEVEL=0 VALIDATION_STRINGENCY=LENIENT \"$MD_BARCODE_TAG\" | /usr/bin/sambamba sort -t $2 -m 18G -o $3 /dev/stdin\nelse\n  /usr/bin/java -Xmx16g -jar /opt/picard/picard.jar MarkDuplicates I=$1 O=/dev/stdout ASSUME_SORT_ORDER=$5 METRICS_FILE=$4 QUIET=true COMPRESSION_LEVEL=0 VALIDATION_STRINGENCY=LENIENT | /usr/bin/sambamba sort -t $2 -m 18G -o $3 /dev/stdin\nfi\n"
                        }
                    ]
                }
            ],
            "arguments": [
                {
                    "position": 2,
                    "valueFrom": "$(runtime.cores)"
                },
                {
                    "position": 4,
                    "valueFrom": "$(inputs.bam.nameroot).mark_dups_metrics.txt"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#mark_duplicates_and_sort.cwl/bam"
                },
                {
                    "type": "string",
                    "default": "queryname",
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#mark_duplicates_and_sort.cwl/input_sort_order"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "MarkedSorted.bam",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#mark_duplicates_and_sort.cwl/output_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).mark_dups_metrics.txt"
                    },
                    "id": "#mark_duplicates_and_sort.cwl/metrics_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_name)"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#mark_duplicates_and_sort.cwl/sorted_bam"
                }
            ],
            "id": "#mark_duplicates_and_sort.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Samtools: merge",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "merge"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000,
                    "coresMin": 4
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                }
            ],
            "arguments": [
                "$(inputs.name).merged.bam",
                {
                    "prefix": "--threads",
                    "valueFrom": "$(runtime.cores)"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#merge_bams_samtools.cwl/bams"
                },
                {
                    "type": "string",
                    "id": "#merge_bams_samtools.cwl/name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.name).merged.bam"
                    },
                    "id": "#merge_bams_samtools.cwl/merged_bam"
                }
            ],
            "id": "#merge_bams_samtools.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "sort BAM by name",
            "baseCommand": [
                "/usr/bin/sambamba",
                "sort"
            ],
            "arguments": [
                "-t",
                {
                    "valueFrom": "$(runtime.cores)"
                },
                "-m",
                "22G",
                "-n",
                "-o",
                {
                    "valueFrom": "$(inputs.bam.nameroot).NameSorted.bam"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 26000,
                    "coresMin": 8
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/sambamba-cwl:0.6.4"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#name_sort.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).NameSorted.bam"
                    },
                    "id": "#name_sort.cwl/name_sorted_bam"
                }
            ],
            "id": "#name_sort.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
